@@ -34,7 +34,7 @@ Rereleased by Ed Singleton, March 2010
 
 from __future__ import generators
 
-import sys, warnings, os, fnmatch, glob, shutil, codecs, hashlib
+import sys, warnings, os, fnmatch, glob, shutil, codecs, hashlib, tempfile
 
 __version__ = '2.2'
 __all__ = ['path', "InsecurePathError"]
@@ -61,6 +61,12 @@ try:
 except AttributeError:
     pass
 
+# Try importing contextlib
+try:
+    import contextlib
+except ImportError:
+    contextlib = None
+
 # Pre-2.3 workaround for booleans
 try:
     True, False
@@ -1048,3 +1054,40 @@ class path(_base):
             raise InsecurePathError(
                 "%r is not a child of %s" % (newpath, self))
         return self.__class__(newpath)
+
+def temp_file():
+    "Create a temp file and return a path object of it"
+    file_name = tempfile.NamedTemporaryFile(delete=False).name
+    return path(file_name)
+
+def temp_dir():
+    dir_name = tempfile.mkdtemp()
+    return path(dir_name)
+
+if contextlib:
+    @contextlib.contextmanager
+    def create_temp_file(content=None, count=1):
+        filenames = [temp_file() for i in range(count)]
+        if content:
+            for filename in filenames:
+                with open(filename, 'w') as opened_file:
+                    opened_file.write(content)
+        if count > 1:
+            yield filenames
+        else:
+            yield filenames[0]
+        for filename in filenames:
+            filename.remove()
+
+    @contextlib.contextmanager
+    def create_temp_dir():
+        temp_dir_name = temp_dir()
+        yield temp_dir_name
+        temp_dir_name.rmtree()
+
+    @contextlib.contextmanager
+    def temp_sys_argv(*args):
+        old_sys_argv = sys.argv
+        sys.argv = args
+        yield
+        sys.argv = old_sys_argv
